@@ -1,3 +1,7 @@
+if (!requireNamespace("ggplot2", quietly = TRUE)) utils::install.packages(
+  "ggplot2", repos = "https://cloud.r-project.org", quiet = TRUE
+)
+
 set.seed(1)
 x <- matrix(rnorm(1500, 0, 1), ncol = 5)
 theta <- rbind(rnorm(5, 0, 1), rnorm(5, 2, 1))
