@@ -1,3 +1,9 @@
+for (package in c("ggplot2", "mvtnorm")) {
+  if (!requireNamespace(package, quietly = TRUE)) utils::install.packages(
+    package, repos = "https://cloud.r-project.org", quiet = TRUE
+  )
+}
+
 set.seed(1)
 n <- 300
 p <- 4
