@@ -2,7 +2,7 @@ testthat::skip("These tests are intended to be run manually.")
 
 testthat::test_that(
   "examples/fastcpd_ts.txt", {
-    testthat::skip_if_not_installed("forecast")
+    testthat::skip_if_not_installed("ggplot2")
 
     examples_ts <- readLines("examples/fastcpd_ts.txt")
     source(textConnection(paste(
